@@ -36,6 +36,6 @@ class WikiTextHtml:
         """Get the link to a file (for the "a href" of the File)."""
         raise NotImplementedError
 
-    def file_get_img(self, url: str, thumb: Optional[int]) -> str:
+    def file_get_img(self, url: str, thumb: Optional[int] = None) -> str:
         """Get the "img src" to a file. If thumb is set, a thumb should be generated of that size."""
         raise NotImplementedError
